Computation times — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Computation times

08:47.984 total execution time for 39 files from all galleries:

Example | Time | Mem (MB)
--- | --- | ---
Plotting 2D band structure (`..\..\examples\00-band_structure\plot_2d_bands.py`) | 02:44.356 | 0.0
Plotting rashba spin splitting (`..\..\examples\03-fermi2d\plot_rashba_spin_spliting.py`) | 01:03.790 | 0.0
Plotting fermi3d isovalue_gif (`..\..\examples\04-fermi3d\plot_fermi3d_isovalue_gif.py`) | 00:30.366 | 0.0
Plotting fermi3d isoslider (`..\..\examples\04-fermi3d\plot_fermi3d_isoslider.py`) | 00:29.115 | 0.0
Autobands plotting (`..\..\examples\00-band_structure\plot_autobands.py`) | 00:23.127 | 0.0
Modifying a POSCAR File: Scaling, Supercells, and Defects (`..\..\examples\06-PyPoscar\plot_utils_pyposcar.py`) | 00:22.359 | 0.0
Plotting Inverse participation ratio (`..\..\examples\00-band_structure\plot_ipr.py`) | 00:21.526 | 0.0
Unfolding Band Structure (`..\..\examples\00-band_structure\plot_unfolding.py`) | 00:20.196 | 0.0
Plotting non colinear dos in Quantum Espresso (`..\..\examples\01-dos\plot_noncolinear_dos_qe.py`) | 00:17.196 | 0.0
Plotting fermi3d cross_section (`..\..\examples\04-fermi3d\plot_fermi3d_cross_section.py`) | 00:15.681 | 0.0
Plotting fermi2d noncolinear (`..\..\examples\03-fermi2d\plot_fermi2d_spin_texture.py`) | 00:15.049 | 0.0
Plotting with Configurations in pyprocar (`..\..\examples\03-fermi2d\plot_fermi2d_configurations.py`) | 00:14.125 | 0.0
Plotting fermi3d spin_texture (`..\..\examples\04-fermi3d\plot_fermi3d_spin_texture.py`) | 00:10.006 | 0.0
Finding defects in a POSCAR file (`..\..\examples\06-PyPoscar\plot_finding_defects_pyposcar.py`) | 00:09.143 | 0.0
Substituting Atoms in a POSCAR File (`..\..\examples\06-PyPoscar\plot_subsitution_pyposcar.py`) | 00:08.542 | 0.0
Visualizing Clusters in Bi2Se3 Slab (`..\..\examples\06-PyPoscar\plot_clusters_pyposcar.py`) | 00:07.662 | 0.0
Plotting fermi3d spin-polarized (`..\..\examples\04-fermi3d\plot_fermi3d_spin-polarized.py`) | 00:07.379 | 0.0
Plotting fermi3d plain (`..\..\examples\04-fermi3d\plot_fermi3d_plain.py`) | 00:04.578 | 0.0
Plotting with Configurations in pyprocar (`..\..\examples\04-fermi3d\plot_fermi3d_configurations.py`) | 00:04.564 | 0.0
Plotting density of states (`..\..\examples\01-dos\plot_colinear_dos.py`) | 00:04.406 | 0.0
Plotting non colinear dos in VASP (`..\..\examples\01-dos\plot_noncolinear_dos_vasp.py`) | 00:04.373 | 0.0
Showing how to get van alphen fequencies from the fermi surface (`..\..\examples\04-fermi3d\plot_de_hass_van_alphen.py`) | 00:04.146 | 0.0
Plotting spin-polarized density of states (`..\..\examples\01-dos\plot_spin_polarized_dos.py`) | 00:03.161 | 0.0
Plotting band structure (`..\..\examples\00-band_structure\plot_colinear.py`) | 00:02.830 | 0.0
Plotting with Configurations in pyprocar (`..\..\examples\00-band_structure\plot_bandsplot_configurations.py`) | 00:02.433 | 0.0
Plotting fermi2d (`..\..\examples\03-fermi2d\plot_fermi2d.py`) | 00:02.414 | 0.0
Plotting non colinear band structures in VASP (`..\..\examples\00-band_structure\plot_noncolinear_vasp.py`) | 00:02.320 | 0.0
Plotting spin polarized band structures (`..\..\examples\00-band_structure\plot_spin_polarized.py`) | 00:02.218 | 0.0
Example of finding the bandgap (`..\..\examples\05-other\plot_ebs.py`) | 00:02.069 | 0.0
Plotting bandsdosplot (`..\..\examples\02-bands_dos\plot_bandsdosplot_configurations.py`) | 00:02.004 | 0.0
Plotting non colinear band structures in Quantum Espresso (`..\..\examples\00-band_structure\plot_noncolinear_qe.py`) | 00:01.505 | 0.0
Plotting with Configurations in pyprocar (`..\..\examples\01-dos\plot_dosplot_configurations.py`) | 00:01.257 | 0.0
Comparing band structures (`..\..\examples\00-band_structure\plot_compare_bands.py`) | 00:01.161 | 0.0
Plotting Atomic Levels (`..\..\examples\00-band_structure\plot_atomic_levels.py`) | 00:01.129 | 0.0
Analyzing Radial Distribution Functions (RDF) (`..\..\examples\06-PyPoscar\plot_rdf_cutoff_pyposcar.py`) | 00:00.531 | 0.0
Example of kpath_generator (`..\..\examples\05-other\plot_kpath_generation.py`) | 00:00.449 | 0.0
Example of kmesh_generator (`..\..\examples\05-other\plot_2dkmesh_generation.py`) | 00:00.380 | 0.0
Plotting bandsdosplot (`..\..\examples\02-bands_dos\plot_bandsdosplot.py`) | 00:00.320 | 0.0
Example of finding the bandgap (`..\..\examples\05-other\plot_bandgap.py`) | 00:00.119 | 0.0